==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/locales/sr_Cyrl_ME.php <==
<?php

return [
    'Names' => [
        'be' => 'бјелоруски',
        'be_BY' => 'бјелоруски (Бјелорусија)',
        'bm' => 'бамананкан',
        'bm_ML' => 'бамананкан (Мали)',
        'bn' => 'бангла',
        'bn_BD' => 'бангла (Бангладеш)',
        'bn_IN' => 'бангла (Индија)',
        'cs_CZ' => 'чешки (Чешка Република)',
        'de_DE' => 'немачки (Њемачка)',
        'en_DE' => 'енглески (Њемачка)',
        'en_KN' => 'енглески (Свети Китс и Невис)',
        'en_UM' => 'енглески (Мања удаљена острва САД)',
        'en_VC' => 'енглески (Свети Винсент и Гренадини)',
        'en_VG' => 'енглески (Британска Дјевичанска Острва)',
        'en_VI' => 'енглески (Америчка Дјевичанска Острва)',
        'ff' => 'фулах',
        'ff_CM' => 'фулах (Камерун)',
        'ff_GN' => 'фулах (Гвинеја)',
        'ff_Latn' => 'фулах (латиница)',
        'ff_Latn_BF' => 'фулах (латиница, Буркина Фасо)',
        'ff_Latn_CM' => 'фулах (латиница, Камерун)',
        'ff_Latn_GH' => 'фулах (латиница, Гана)',
        'ff_Latn_GM' => 'фулах (латиница, Гамбија)',
        'ff_Latn_GN' => 'фулах (латиница, Гвинеја)',
        'ff_Latn_GW' => 'фулах (латиница, Гвинеја-Бисао)',
        'ff_Latn_LR' => 'фулах (латиница, Либерија)',
        'ff_Latn_MR' => 'фулах (латиница, Мауританија)',
        'ff_Latn_NE' => 'фулах (латиница, Нигер)',
        'ff_Latn_NG' => 'фулах (латиница, Нигерија)',
        'ff_Latn_SL' => 'фулах (латиница, Сијера Леоне)',
        'ff_Latn_SN' => 'фулах (латиница, Сенегал)',
        'ff_MR' => 'фулах (Мауританија)',
        'ff_SN' => 'фулах (Сенегал)',
        'fr_CG' => 'француски (Конго)',
        'fr_PM' => 'француски (Свети Пјер и Микелон)',
        'fr_RE' => 'француски (Реунион)',
        'ln_CG' => 'лингала (Конго)',
        'lo' => 'лаошки',
        'lo_LA' => 'лаошки (Лаос)',
        'ru_BY' => 'руски (Бјелорусија)',
        'xh' => 'исикоса',
        'xh_ZA' => 'исикоса (Јужноафричка Република)',
        'zu' => 'исизулу',
        'zu_ZA' => 'исизулу (Јужноафричка Република)',
    ],
];

==> symfony_7.3.4+dfsg.orig.tar.xz: symfony-7.3.4/src/Symfony/Component/Intl/Resources/data/locales/sr_Cyrl_ME.php <==
<?php

return [
    'Names' => [
        'be' => 'бјелоруски',
        'be_BY' => 'бјелоруски (Бјелорусија)',
        'bm' => 'бамананкан',
        'bm_ML' => 'бамананкан (Мали)',
        'bn' => 'бангла',
        'bn_BD' => 'бангла (Бангладеш)',
        'bn_IN' => 'бангла (Индија)',
        'cs_CZ' => 'чешки (Чешка Република)',
        'de_DE' => 'немачки (Њемачка)',
        'en_CZ' => 'енглески (Чешка Република)',
        'en_DE' => 'енглески (Њемачка)',
        'en_KN' => 'енглески (Свети Китс и Невис)',
        'en_UM' => 'енглески (Мања удаљена острва САД)',
        'en_VC' => 'енглески (Свети Винсент и Гренадини)',
        'en_VG' => 'енглески (Британска Дјевичанска Острва)',
        'en_VI' => 'енглески (Америчка Дјевичанска Острва)',
        'ff' => 'фулах',
        'ff_Adlm' => 'фулах (адлам)',
        'ff_Adlm_BF' => 'фулах (адлам, Буркина Фасо)',
        'ff_Adlm_CM' => 'фулах (адлам, Камерун)',
        'ff_Adlm_GH' => 'фулах (адлам, Гана)',
        'ff_Adlm_GM' => 'фулах (адлам, Гамбија)',
        'ff_Adlm_GN' => 'фулах (адлам, Гвинеја)',
        'ff_Adlm_GW' => 'фулах (адлам, Гвинеја-Бисао)',
        'ff_Adlm_LR' => 'фулах (адлам, Либерија)',
        'ff_Adlm_MR' => 'фулах (адлам, Мауританија)',
        'ff_Adlm_NE' => 'фулах (адлам, Нигер)',
        'ff_Adlm_NG' => 'фулах (адлам, Нигерија)',
        'ff_Adlm_SL' => 'фулах (адлам, Сијера Леоне)',
        'ff_Adlm_SN' => 'фулах (адлам, Сенегал)',
        'ff_CM' => 'фулах (Камерун)',
        'ff_GN' => 'фулах (Гвинеја)',
        'ff_Latn' => 'фулах (латиница)',
        'ff_Latn_BF' => 'фулах (латиница, Буркина Фасо)',
        'ff_Latn_CM' => 'фулах (латиница, Камерун)',
        'ff_Latn_GH' => 'фулах (латиница, Гана)',
        'ff_Latn_GM' => 'фулах (латиница, Гамбија)',
        'ff_Latn_GN' => 'фулах (латиница, Гвинеја)',
        'ff_Latn_GW' => 'фулах (латиница, Гвинеја-Бисао)',
        'ff_Latn_LR' => 'фулах (латиница, Либерија)',
        'ff_Latn_MR' => 'фулах (латиница, Мауританија)',
        'ff_Latn_NE' => 'фулах (латиница, Нигер)',
        'ff_Latn_NG' => 'фулах (латиница, Нигерија)',
        'ff_Latn_SL' => 'фулах (латиница, Сијера Леоне)',
        'ff_Latn_SN' => 'фулах (латиница, Сенегал)',
        'ff_MR' => 'фулах (Мауританија)',
        'ff_SN' => 'фулах (Сенегал)',
        'fr_CG' => 'француски (Конго)',
        'fr_PM' => 'француски (Свети Пјер и Микелон)',
        'fr_RE' => 'француски (Реунион)',
        'ln_CG' => 'лингала (Конго)',
        'lo' => 'лаошки',
        'lo_LA' => 'лаошки (Лаос)',
        'ru_BY' => 'руски (Бјелорусија)',
        'xh' => 'исикоса',
        'xh_ZA' => 'исикоса (Јужноафричка Република)',
        'zu' => 'исизулу',
        'zu_ZA' => 'исизулу (Јужноафричка Република)',
    ],
];
